@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-traindat = '../data/fm_train_real.dat'
-testdat = '../data/fm_test_real.dat'
+traindat = '../data/fm_train_hist.dat'
+testdat = '../data/fm_test_hist.dat'
 
 parameter_list = [[traindat,testdat,1.4,10], [traindat,testdat,1.5,10]]
 
 def kernel_chi2_modular (train_fname=traindat,test_fname=testdat,width=1.4, size_cache=10):
-	from modshogun import RealFeatures, Chi2Kernel, CSVFile
+	from modshogun import RealFeatures, Chi2Kernel, CSVFile, NormOne
 
 	feats_train=RealFeatures(CSVFile(train_fname))
 	feats_test=RealFeatures(CSVFile(test_fname))
